# UserMail Converter

A simple GUI tool made with python and PyQt5, used to convert between emails and usernames.

## Key Features
- [x] Import or Export accounts
- [x] Convert Emails to Usernames and the other way around
- [x] Support lists with passwords (separated by ":" only)
- [x] Simple Interface
- [x] It works and it's not a virus ;D
	### Todo
	i don't know ! but feel free to suggest anything you want to be included.

## Installation
### Pypi (preferred)
	$ pip install -U usermail-converter
to launch the app after installation use the command 

    $ usermail-converter

### Windows Executable
Binaries for windows are available under [releases](https://github.com/ThamiMemel/UserMail_Converter/releases)
### Linux Executable
Binaries for Linux  are available under [releases](https://github.com/ThamiMemel/UserMail_Converter/releases)
## Modes
#### Email to Username 
	user@domaine.com > user
#### Email:Password to Username:Password
	user@domaine.com:pass > user:pass
#### Username to Email
	user > user@domain.com
#### Username:Password to Email:Password
	user:pass > user@domain.com:pass
## Disclaimer
By using this software, you agree that you are responsible for your actions when using it.

